## dbt-redshift 1.9.3 - April 01, 2025

### Features

- Add IdpTokenAuthPlugin authentication method. ([#898](https://github.com/dbt-labs/dbt-adapters/issues/898))
- Make source and target tables able to be referenced via DBT_INTERNAL_DEST and DBT_INTERNAL_SOURCE for the delete/insert incremental strategy ([#910](https://github.com/dbt-labs/dbt-adapters/issues/910))

### Under the Hood

- Add retry logic for retryable exceptions ([#960](https://github.com/dbt-labs/dbt-adapters/issues/960))
- Move from setup.py to pyproject.toml and to hatch as a dev tool ([#951](https://github.com/dbt-labs/dbt-adapters/issues/951))
- Refactor to use new batch context varaibles ([#966](https://github.com/dbt-labs/dbt-adapters/issues/966))
